@@ -10,8 +10,9 @@
   by Matt Koss <koss@miesto.sk>
 
   KMail is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2 or above,
-  as published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   KMail is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -63,7 +64,7 @@ StatusbarProgressWidget::StatusbarProgressWidget(ProgressDialog *progressDialog,
     , mShowButton(button)
     , mProgressDialog(progressDialog)
 {
-    int w = fontMetrics().width(QStringLiteral(" 999.9 kB/s 00:00:01 ")) + 8;
+    int w = fontMetrics().boundingRect(QStringLiteral(" 999.9 kB/s 00:00:01 ")).width() + 8;
     QHBoxLayout *boxLayout = new QHBoxLayout(this);
     boxLayout->setObjectName(QStringLiteral("boxLayout"));
     boxLayout->setMargin(0);
